@@ -489,10 +489,12 @@ QT_WARNING_POP
     inline QString getActivityKey()
     {
 #ifdef HAVE_KACTIVITIES
-        return activityAware ? activitiesConsumer.currentActivity() : nulluuid;
-#else
-        return nulluuid;
+        if (activityAware) {
+            const QString currentActivity =  activitiesConsumer.currentActivity();
+            return currentActivity.isEmpty() ? nulluuid : currentActivity;
+        }
 #endif
+        return nulluuid;
     }
 
     void addToHistory()
@@ -797,10 +799,12 @@ QList<QueryMatch> RunnerManager::matches() const
     return d->context.matches();
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 79)
 void RunnerManager::run(const QString &matchId)
 {
     run(d->context.match(matchId));
 }
+#endif
 
 void RunnerManager::run(const QueryMatch &match)
 {
@@ -828,7 +832,7 @@ void RunnerManager::run(const QueryMatch &match)
 bool RunnerManager::runMatch(const QueryMatch &match)
 {
     d->addToHistory();
-    if (match.type() == Plasma::QueryMatch::InformationalMatch) {
+    if (match.type() == Plasma::QueryMatch::InformationalMatch && !match.selectedAction()) {
         const QString info = match.data().toString();
         if (!info.isEmpty()) {
             Q_EMIT setSearchTerm(info, info.length());
@@ -848,10 +852,12 @@ QList<QAction*> RunnerManager::actionsForMatch(const QueryMatch &match)
     return QList<QAction*>();
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 79)
 QMimeData * RunnerManager::mimeDataForMatch(const QString &id) const
 {
     return mimeDataForMatch(d->context.match(id));
 }
+#endif
 
 
 QMimeData * RunnerManager::mimeDataForMatch(const QueryMatch &match) const
